@@ -161,7 +161,8 @@ class _Elements():
         #end if
         #
         try:
-            self._document.Elements.Add(element_name, x_pos, y_pos, rotation, flipped)
+            new_element = self._document.Elements.Add(element_name, x_pos, y_pos, rotation, flipped)
+            self._elements_dict[new_element.Name] = _Element(self._document.Elements(new_element.Name), self._document_type)
         except:
             raise RuntimeError('Error when adding element: '+element_name)
         #end try
@@ -192,6 +193,7 @@ class _Elements():
                 if self._document.Elements[ele_idx].Name == element_name_n_id:
                     self._document.Elements.Remove(ele_idx+1)
                     element_removed = True
+                    self._elements_dict.pop(element_name_n_id)
                     break
                 #end if
             #end for
